greenheart.simulation.technologies.hydrogen.electrolysis.PEM\_tools
===================================================================

.. automodule:: greenheart.simulation.technologies.hydrogen.electrolysis.PEM_tools

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      check_capacity_based_on_clusters
      create_1MW_reference_PEM
      get_electrolyzer_BOL_efficiency
      size_electrolyzer_for_hydrogen_demand
   
   

   
   
   

   
   
   



